@@ -9,4 +9,13 @@ java_script <- function(...) {
     stop("The arguments for JS() must be a character vector")
   x <- paste(x, collapse = '\n')
   structure(x, class = unique(c("JS_EVAL", oldClass(x))))
+}
+
+## FILE_EXT --------------------------------------------------------------------
+
+#' Get file extensions from file names
+#' @noRd
+file_ext <- function(x) {
+  pos <- regexpr("\\.([[:alnum:]]+)$", x)
+  ifelse(pos > -1L, substring(x, pos + 1L), "")
 }
\ No newline at end of file
